/****************************************************************************
** Meta object code from reading C++ file 'takephotosettingareawidget.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.18)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../src/takephotosettingareawidget.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'takephotosettingareawidget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.18. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_takePhotoSettingAreaWidget_t {
    QByteArrayData data[35];
    char stringdata0[558];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_takePhotoSettingAreaWidget_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_takePhotoSettingAreaWidget_t qt_meta_stringdata_takePhotoSettingAreaWidget = {
    {
QT_MOC_LITERAL(0, 0, 26), // "takePhotoSettingAreaWidget"
QT_MOC_LITERAL(1, 27, 20), // "sngSetDelayTakePhoto"
QT_MOC_LITERAL(2, 48, 0), // ""
QT_MOC_LITERAL(3, 49, 9), // "delayTime"
QT_MOC_LITERAL(4, 59, 16), // "sngSetFlashlight"
QT_MOC_LITERAL(5, 76, 13), // "bFlashlightOn"
QT_MOC_LITERAL(6, 90, 16), // "sngFilterChanged"
QT_MOC_LITERAL(7, 107, 11), // "efilterType"
QT_MOC_LITERAL(8, 119, 17), // "sngShowFilterName"
QT_MOC_LITERAL(9, 137, 5), // "bShow"
QT_MOC_LITERAL(10, 143, 16), // "sngSetFilterName"
QT_MOC_LITERAL(11, 160, 4), // "name"
QT_MOC_LITERAL(12, 165, 18), // "sigExposureChanged"
QT_MOC_LITERAL(13, 184, 8), // "exposure"
QT_MOC_LITERAL(14, 193, 21), // "sigFilterGroupDisplay"
QT_MOC_LITERAL(15, 215, 8), // "bDisplay"
QT_MOC_LITERAL(16, 224, 14), // "foldBtnClicked"
QT_MOC_LITERAL(17, 239, 10), // "isShortcut"
QT_MOC_LITERAL(18, 250, 16), // "unfoldBtnClicked"
QT_MOC_LITERAL(19, 267, 24), // "flashlightFoldBtnClicked"
QT_MOC_LITERAL(20, 292, 26), // "flashlightUnfoldBtnClicked"
QT_MOC_LITERAL(21, 319, 21), // "delayUnfoldBtnClicked"
QT_MOC_LITERAL(22, 341, 19), // "delayfoldBtnClicked"
QT_MOC_LITERAL(23, 361, 23), // "filtersUnfoldBtnClicked"
QT_MOC_LITERAL(24, 385, 21), // "filtersFoldBtnClicked"
QT_MOC_LITERAL(25, 407, 18), // "onDelayBtnsClicked"
QT_MOC_LITERAL(26, 426, 23), // "onFlashlightBtnsClicked"
QT_MOC_LITERAL(27, 450, 19), // "onFilterBtnsClicked"
QT_MOC_LITERAL(28, 470, 19), // "onUpdateFilterImage"
QT_MOC_LITERAL(29, 490, 7), // "QImage*"
QT_MOC_LITERAL(30, 498, 3), // "img"
QT_MOC_LITERAL(31, 502, 22), // "onExposureValueChanged"
QT_MOC_LITERAL(32, 525, 5), // "value"
QT_MOC_LITERAL(33, 531, 18), // "exposureBtnClicked"
QT_MOC_LITERAL(34, 550, 7) // "opacity"

    },
    "takePhotoSettingAreaWidget\0"
    "sngSetDelayTakePhoto\0\0delayTime\0"
    "sngSetFlashlight\0bFlashlightOn\0"
    "sngFilterChanged\0efilterType\0"
    "sngShowFilterName\0bShow\0sngSetFilterName\0"
    "name\0sigExposureChanged\0exposure\0"
    "sigFilterGroupDisplay\0bDisplay\0"
    "foldBtnClicked\0isShortcut\0unfoldBtnClicked\0"
    "flashlightFoldBtnClicked\0"
    "flashlightUnfoldBtnClicked\0"
    "delayUnfoldBtnClicked\0delayfoldBtnClicked\0"
    "filtersUnfoldBtnClicked\0filtersFoldBtnClicked\0"
    "onDelayBtnsClicked\0onFlashlightBtnsClicked\0"
    "onFilterBtnsClicked\0onUpdateFilterImage\0"
    "QImage*\0img\0onExposureValueChanged\0"
    "value\0exposureBtnClicked\0opacity"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_takePhotoSettingAreaWidget[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      33,   14, // methods
       1,  254, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       7,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,  179,    2, 0x06 /* Public */,
       4,    1,  182,    2, 0x06 /* Public */,
       6,    1,  185,    2, 0x06 /* Public */,
       8,    1,  188,    2, 0x06 /* Public */,
      10,    1,  191,    2, 0x06 /* Public */,
      12,    1,  194,    2, 0x06 /* Public */,
      14,    1,  197,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      16,    1,  200,    2, 0x0a /* Public */,
      16,    0,  203,    2, 0x2a /* Public | MethodCloned */,
      18,    1,  204,    2, 0x0a /* Public */,
      18,    0,  207,    2, 0x2a /* Public | MethodCloned */,
      19,    1,  208,    2, 0x0a /* Public */,
      19,    0,  211,    2, 0x2a /* Public | MethodCloned */,
      20,    1,  212,    2, 0x0a /* Public */,
      20,    0,  215,    2, 0x2a /* Public | MethodCloned */,
      21,    1,  216,    2, 0x0a /* Public */,
      21,    0,  219,    2, 0x2a /* Public | MethodCloned */,
      22,    1,  220,    2, 0x0a /* Public */,
      22,    0,  223,    2, 0x2a /* Public | MethodCloned */,
      23,    1,  224,    2, 0x0a /* Public */,
      23,    0,  227,    2, 0x2a /* Public | MethodCloned */,
      24,    1,  228,    2, 0x0a /* Public */,
      24,    0,  231,    2, 0x2a /* Public | MethodCloned */,
      25,    1,  232,    2, 0x0a /* Public */,
      25,    0,  235,    2, 0x2a /* Public | MethodCloned */,
      26,    1,  236,    2, 0x0a /* Public */,
      26,    0,  239,    2, 0x2a /* Public | MethodCloned */,
      27,    1,  240,    2, 0x0a /* Public */,
      27,    0,  243,    2, 0x2a /* Public | MethodCloned */,
      28,    1,  244,    2, 0x0a /* Public */,
      31,    1,  247,    2, 0x0a /* Public */,
      33,    1,  250,    2, 0x0a /* Public */,
      33,    0,  253,    2, 0x2a /* Public | MethodCloned */,

 // signals: parameters
    QMetaType::Void, QMetaType::Int,    3,
    QMetaType::Void, QMetaType::Bool,    5,
    QMetaType::Void, 0x80000000 | 7,    7,
    QMetaType::Void, QMetaType::Bool,    9,
    QMetaType::Void, QMetaType::QString,   11,
    QMetaType::Void, QMetaType::Int,   13,
    QMetaType::Void, QMetaType::Bool,   15,

 // slots: parameters
    QMetaType::Void, QMetaType::Bool,   17,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   17,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   17,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   17,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   17,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   17,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   17,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   17,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   17,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   17,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   17,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 29,   30,
    QMetaType::Void, QMetaType::Int,   32,
    QMetaType::Void, QMetaType::Bool,   17,
    QMetaType::Void,

 // properties: name, type, flags
      34, QMetaType::Int, 0x00095103,

       0        // eod
};

void takePhotoSettingAreaWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<takePhotoSettingAreaWidget *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->sngSetDelayTakePhoto((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 1: _t->sngSetFlashlight((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 2: _t->sngFilterChanged((*reinterpret_cast< efilterType(*)>(_a[1]))); break;
        case 3: _t->sngShowFilterName((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 4: _t->sngSetFilterName((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 5: _t->sigExposureChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 6: _t->sigFilterGroupDisplay((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 7: _t->foldBtnClicked((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 8: _t->foldBtnClicked(); break;
        case 9: _t->unfoldBtnClicked((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 10: _t->unfoldBtnClicked(); break;
        case 11: _t->flashlightFoldBtnClicked((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 12: _t->flashlightFoldBtnClicked(); break;
        case 13: _t->flashlightUnfoldBtnClicked((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 14: _t->flashlightUnfoldBtnClicked(); break;
        case 15: _t->delayUnfoldBtnClicked((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 16: _t->delayUnfoldBtnClicked(); break;
        case 17: _t->delayfoldBtnClicked((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 18: _t->delayfoldBtnClicked(); break;
        case 19: _t->filtersUnfoldBtnClicked((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 20: _t->filtersUnfoldBtnClicked(); break;
        case 21: _t->filtersFoldBtnClicked((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 22: _t->filtersFoldBtnClicked(); break;
        case 23: _t->onDelayBtnsClicked((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 24: _t->onDelayBtnsClicked(); break;
        case 25: _t->onFlashlightBtnsClicked((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 26: _t->onFlashlightBtnsClicked(); break;
        case 27: _t->onFilterBtnsClicked((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 28: _t->onFilterBtnsClicked(); break;
        case 29: _t->onUpdateFilterImage((*reinterpret_cast< QImage*(*)>(_a[1]))); break;
        case 30: _t->onExposureValueChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 31: _t->exposureBtnClicked((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 32: _t->exposureBtnClicked(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (takePhotoSettingAreaWidget::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&takePhotoSettingAreaWidget::sngSetDelayTakePhoto)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (takePhotoSettingAreaWidget::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&takePhotoSettingAreaWidget::sngSetFlashlight)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (takePhotoSettingAreaWidget::*)(efilterType );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&takePhotoSettingAreaWidget::sngFilterChanged)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (takePhotoSettingAreaWidget::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&takePhotoSettingAreaWidget::sngShowFilterName)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (takePhotoSettingAreaWidget::*)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&takePhotoSettingAreaWidget::sngSetFilterName)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (takePhotoSettingAreaWidget::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&takePhotoSettingAreaWidget::sigExposureChanged)) {
                *result = 5;
                return;
            }
        }
        {
            using _t = void (takePhotoSettingAreaWidget::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&takePhotoSettingAreaWidget::sigFilterGroupDisplay)) {
                *result = 6;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<takePhotoSettingAreaWidget *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< int*>(_v) = _t->getOpacity(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<takePhotoSettingAreaWidget *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setOpacity(*reinterpret_cast< int*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

QT_INIT_METAOBJECT const QMetaObject takePhotoSettingAreaWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_meta_stringdata_takePhotoSettingAreaWidget.data,
    qt_meta_data_takePhotoSettingAreaWidget,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *takePhotoSettingAreaWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *takePhotoSettingAreaWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_takePhotoSettingAreaWidget.stringdata0))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int takePhotoSettingAreaWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 33)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 33;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 33)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 33;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 1;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void takePhotoSettingAreaWidget::sngSetDelayTakePhoto(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void takePhotoSettingAreaWidget::sngSetFlashlight(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void takePhotoSettingAreaWidget::sngFilterChanged(efilterType _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void takePhotoSettingAreaWidget::sngShowFilterName(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void takePhotoSettingAreaWidget::sngSetFilterName(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void takePhotoSettingAreaWidget::sigExposureChanged(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void takePhotoSettingAreaWidget::sigFilterGroupDisplay(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 6, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
