/****************************************************************************
** Meta object code from reading C++ file 'videowidget.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.18)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../src/videowidget.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'videowidget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.18. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_QGraphicsViewEx_t {
    QByteArrayData data[1];
    char stringdata0[16];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_QGraphicsViewEx_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_QGraphicsViewEx_t qt_meta_stringdata_QGraphicsViewEx = {
    {
QT_MOC_LITERAL(0, 0, 15) // "QGraphicsViewEx"

    },
    "QGraphicsViewEx"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_QGraphicsViewEx[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void QGraphicsViewEx::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject QGraphicsViewEx::staticMetaObject = { {
    QMetaObject::SuperData::link<QGraphicsView::staticMetaObject>(),
    qt_meta_stringdata_QGraphicsViewEx.data,
    qt_meta_data_QGraphicsViewEx,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *QGraphicsViewEx::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QGraphicsViewEx::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_QGraphicsViewEx.stringdata0))
        return static_cast<void*>(this);
    return QGraphicsView::qt_metacast(_clname);
}

int QGraphicsViewEx::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QGraphicsView::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_videowidget_t {
    QByteArrayData data[52];
    char stringdata0[695];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_videowidget_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_videowidget_t qt_meta_stringdata_videowidget = {
    {
QT_MOC_LITERAL(0, 0, 11), // "videowidget"
QT_MOC_LITERAL(1, 12, 15), // "sigDeviceChange"
QT_MOC_LITERAL(2, 28, 0), // ""
QT_MOC_LITERAL(3, 29, 13), // "takePicCancel"
QT_MOC_LITERAL(4, 43, 11), // "takePicDone"
QT_MOC_LITERAL(5, 55, 11), // "takePicOnce"
QT_MOC_LITERAL(6, 67, 12), // "takeVdCancel"
QT_MOC_LITERAL(7, 80, 10), // "takeVdDone"
QT_MOC_LITERAL(8, 91, 17), // "updateBlockSystem"
QT_MOC_LITERAL(9, 109, 5), // "bTrue"
QT_MOC_LITERAL(10, 115, 5), // "noCam"
QT_MOC_LITERAL(11, 121, 14), // "noCamAvailable"
QT_MOC_LITERAL(12, 136, 12), // "camAvailable"
QT_MOC_LITERAL(13, 149, 8), // "filename"
QT_MOC_LITERAL(14, 158, 11), // "strFilename"
QT_MOC_LITERAL(15, 170, 19), // "switchCameraSuccess"
QT_MOC_LITERAL(16, 190, 7), // "devName"
QT_MOC_LITERAL(17, 198, 17), // "updateRecordState"
QT_MOC_LITERAL(18, 216, 5), // "state"
QT_MOC_LITERAL(19, 222, 16), // "updatePhotoState"
QT_MOC_LITERAL(20, 239, 17), // "updateFilterImage"
QT_MOC_LITERAL(21, 257, 7), // "QImage*"
QT_MOC_LITERAL(22, 265, 5), // "image"
QT_MOC_LITERAL(23, 271, 20), // "reflushSnapshotLabel"
QT_MOC_LITERAL(24, 292, 9), // "onTakePic"
QT_MOC_LITERAL(25, 302, 11), // "onTakeVideo"
QT_MOC_LITERAL(26, 314, 13), // "showCountdown"
QT_MOC_LITERAL(27, 328, 11), // "showRecTime"
QT_MOC_LITERAL(28, 340, 11), // "onChangeDev"
QT_MOC_LITERAL(29, 352, 15), // "onEndBtnClicked"
QT_MOC_LITERAL(30, 368, 16), // "onRestartDevices"
QT_MOC_LITERAL(31, 385, 18), // "onThemeTypeChanged"
QT_MOC_LITERAL(32, 404, 32), // "DGuiApplicationHelper::ColorType"
QT_MOC_LITERAL(33, 437, 9), // "themeType"
QT_MOC_LITERAL(34, 447, 17), // "onExposureChanged"
QT_MOC_LITERAL(35, 465, 8), // "exposure"
QT_MOC_LITERAL(36, 474, 22), // "onFilterDisplayChanged"
QT_MOC_LITERAL(37, 497, 8), // "bDisplay"
QT_MOC_LITERAL(38, 506, 17), // "ReceiveMajorImage"
QT_MOC_LITERAL(39, 524, 6), // "result"
QT_MOC_LITERAL(40, 531, 19), // "ReceiveOpenGLstatus"
QT_MOC_LITERAL(41, 551, 23), // "onReachMaxDelayedFrames"
QT_MOC_LITERAL(42, 575, 5), // "flash"
QT_MOC_LITERAL(43, 581, 21), // "slotresolutionchanged"
QT_MOC_LITERAL(44, 603, 19), // "slotGridTypeChanged"
QT_MOC_LITERAL(45, 623, 22), // "slotVideoFormatChanged"
QT_MOC_LITERAL(46, 646, 13), // "onRecordFrame"
QT_MOC_LITERAL(47, 660, 6), // "uchar*"
QT_MOC_LITERAL(48, 667, 3), // "yuv"
QT_MOC_LITERAL(49, 671, 4), // "size"
QT_MOC_LITERAL(50, 676, 13), // "onRecordAudio"
QT_MOC_LITERAL(51, 690, 4) // "data"

    },
    "videowidget\0sigDeviceChange\0\0takePicCancel\0"
    "takePicDone\0takePicOnce\0takeVdCancel\0"
    "takeVdDone\0updateBlockSystem\0bTrue\0"
    "noCam\0noCamAvailable\0camAvailable\0"
    "filename\0strFilename\0switchCameraSuccess\0"
    "devName\0updateRecordState\0state\0"
    "updatePhotoState\0updateFilterImage\0"
    "QImage*\0image\0reflushSnapshotLabel\0"
    "onTakePic\0onTakeVideo\0showCountdown\0"
    "showRecTime\0onChangeDev\0onEndBtnClicked\0"
    "onRestartDevices\0onThemeTypeChanged\0"
    "DGuiApplicationHelper::ColorType\0"
    "themeType\0onExposureChanged\0exposure\0"
    "onFilterDisplayChanged\0bDisplay\0"
    "ReceiveMajorImage\0result\0ReceiveOpenGLstatus\0"
    "onReachMaxDelayedFrames\0flash\0"
    "slotresolutionchanged\0slotGridTypeChanged\0"
    "slotVideoFormatChanged\0onRecordFrame\0"
    "uchar*\0yuv\0size\0onRecordAudio\0data"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_videowidget[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      35,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
      16,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,  189,    2, 0x06 /* Public */,
       3,    0,  190,    2, 0x06 /* Public */,
       4,    0,  191,    2, 0x06 /* Public */,
       5,    0,  192,    2, 0x06 /* Public */,
       6,    0,  193,    2, 0x06 /* Public */,
       7,    0,  194,    2, 0x06 /* Public */,
       8,    1,  195,    2, 0x06 /* Public */,
      10,    0,  198,    2, 0x06 /* Public */,
      11,    0,  199,    2, 0x06 /* Public */,
      12,    0,  200,    2, 0x06 /* Public */,
      13,    1,  201,    2, 0x06 /* Public */,
      15,    1,  204,    2, 0x06 /* Public */,
      17,    1,  207,    2, 0x06 /* Public */,
      19,    1,  210,    2, 0x06 /* Public */,
      20,    1,  213,    2, 0x06 /* Public */,
      23,    0,  216,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      24,    1,  217,    2, 0x0a /* Public */,
      25,    0,  220,    2, 0x0a /* Public */,
      26,    0,  221,    2, 0x0a /* Public */,
      27,    0,  222,    2, 0x0a /* Public */,
      28,    0,  223,    2, 0x0a /* Public */,
      29,    0,  224,    2, 0x0a /* Public */,
      30,    0,  225,    2, 0x0a /* Public */,
      31,    1,  226,    2, 0x0a /* Public */,
      34,    1,  229,    2, 0x0a /* Public */,
      36,    1,  232,    2, 0x0a /* Public */,
      38,    2,  235,    2, 0x08 /* Private */,
      40,    1,  240,    2, 0x08 /* Private */,
      41,    0,  243,    2, 0x08 /* Private */,
      42,    0,  244,    2, 0x08 /* Private */,
      43,    1,  245,    2, 0x08 /* Private */,
      44,    1,  248,    2, 0x08 /* Private */,
      45,    1,  251,    2, 0x08 /* Private */,
      46,    2,  254,    2, 0x08 /* Private */,
      50,    2,  259,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,    9,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,   14,
    QMetaType::Void, QMetaType::QString,   16,
    QMetaType::Void, QMetaType::Int,   18,
    QMetaType::Void, QMetaType::Int,   18,
    QMetaType::Void, 0x80000000 | 21,   22,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void, QMetaType::Bool,    9,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 32,   33,
    QMetaType::Void, QMetaType::Int,   35,
    QMetaType::Void, QMetaType::Int,   37,
    QMetaType::Void, 0x80000000 | 21, QMetaType::Int,   22,   39,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void, 0x80000000 | 47, QMetaType::UInt,   48,   49,
    QMetaType::Void, 0x80000000 | 47, QMetaType::UInt,   51,   49,

       0        // eod
};

void videowidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<videowidget *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->sigDeviceChange(); break;
        case 1: _t->takePicCancel(); break;
        case 2: _t->takePicDone(); break;
        case 3: _t->takePicOnce(); break;
        case 4: _t->takeVdCancel(); break;
        case 5: _t->takeVdDone(); break;
        case 6: _t->updateBlockSystem((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 7: _t->noCam(); break;
        case 8: _t->noCamAvailable(); break;
        case 9: _t->camAvailable(); break;
        case 10: _t->filename((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 11: _t->switchCameraSuccess((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 12: _t->updateRecordState((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 13: _t->updatePhotoState((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 14: _t->updateFilterImage((*reinterpret_cast< QImage*(*)>(_a[1]))); break;
        case 15: _t->reflushSnapshotLabel(); break;
        case 16: _t->onTakePic((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 17: _t->onTakeVideo(); break;
        case 18: _t->showCountdown(); break;
        case 19: _t->showRecTime(); break;
        case 20: _t->onChangeDev(); break;
        case 21: _t->onEndBtnClicked(); break;
        case 22: _t->onRestartDevices(); break;
        case 23: _t->onThemeTypeChanged((*reinterpret_cast< DGuiApplicationHelper::ColorType(*)>(_a[1]))); break;
        case 24: _t->onExposureChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 25: _t->onFilterDisplayChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 26: _t->ReceiveMajorImage((*reinterpret_cast< QImage*(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 27: _t->ReceiveOpenGLstatus((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 28: _t->onReachMaxDelayedFrames(); break;
        case 29: _t->flash(); break;
        case 30: _t->slotresolutionchanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 31: _t->slotGridTypeChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 32: _t->slotVideoFormatChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 33: _t->onRecordFrame((*reinterpret_cast< uchar*(*)>(_a[1])),(*reinterpret_cast< uint(*)>(_a[2]))); break;
        case 34: _t->onRecordAudio((*reinterpret_cast< uchar*(*)>(_a[1])),(*reinterpret_cast< uint(*)>(_a[2]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (videowidget::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&videowidget::sigDeviceChange)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (videowidget::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&videowidget::takePicCancel)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (videowidget::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&videowidget::takePicDone)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (videowidget::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&videowidget::takePicOnce)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (videowidget::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&videowidget::takeVdCancel)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (videowidget::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&videowidget::takeVdDone)) {
                *result = 5;
                return;
            }
        }
        {
            using _t = void (videowidget::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&videowidget::updateBlockSystem)) {
                *result = 6;
                return;
            }
        }
        {
            using _t = void (videowidget::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&videowidget::noCam)) {
                *result = 7;
                return;
            }
        }
        {
            using _t = void (videowidget::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&videowidget::noCamAvailable)) {
                *result = 8;
                return;
            }
        }
        {
            using _t = void (videowidget::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&videowidget::camAvailable)) {
                *result = 9;
                return;
            }
        }
        {
            using _t = void (videowidget::*)(QString );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&videowidget::filename)) {
                *result = 10;
                return;
            }
        }
        {
            using _t = void (videowidget::*)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&videowidget::switchCameraSuccess)) {
                *result = 11;
                return;
            }
        }
        {
            using _t = void (videowidget::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&videowidget::updateRecordState)) {
                *result = 12;
                return;
            }
        }
        {
            using _t = void (videowidget::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&videowidget::updatePhotoState)) {
                *result = 13;
                return;
            }
        }
        {
            using _t = void (videowidget::*)(QImage * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&videowidget::updateFilterImage)) {
                *result = 14;
                return;
            }
        }
        {
            using _t = void (videowidget::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&videowidget::reflushSnapshotLabel)) {
                *result = 15;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject videowidget::staticMetaObject = { {
    QMetaObject::SuperData::link<DWidget::staticMetaObject>(),
    qt_meta_stringdata_videowidget.data,
    qt_meta_data_videowidget,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *videowidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *videowidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_videowidget.stringdata0))
        return static_cast<void*>(this);
    return DWidget::qt_metacast(_clname);
}

int videowidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = DWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 35)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 35;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 35)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 35;
    }
    return _id;
}

// SIGNAL 0
void videowidget::sigDeviceChange()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void videowidget::takePicCancel()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void videowidget::takePicDone()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void videowidget::takePicOnce()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void videowidget::takeVdCancel()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void videowidget::takeVdDone()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void videowidget::updateBlockSystem(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 6, _a);
}

// SIGNAL 7
void videowidget::noCam()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void videowidget::noCamAvailable()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void videowidget::camAvailable()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void videowidget::filename(QString _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 10, _a);
}

// SIGNAL 11
void videowidget::switchCameraSuccess(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 11, _a);
}

// SIGNAL 12
void videowidget::updateRecordState(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 12, _a);
}

// SIGNAL 13
void videowidget::updatePhotoState(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 13, _a);
}

// SIGNAL 14
void videowidget::updateFilterImage(QImage * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 14, _a);
}

// SIGNAL 15
void videowidget::reflushSnapshotLabel()
{
    QMetaObject::activate(this, &staticMetaObject, 15, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
